import { defineConfig } from 'vite';
import { resolve } from 'path';
import vue from '@vitejs/plugin-vue';
import viteCompression from 'vite-plugin-compression';
import styleImport from 'vite-plugin-style-import';
import autoImport from 'unplugin-auto-import/vite'
// https://vitejs.dev/config/
const buildTimeStep = new Date().getTime()

export default defineConfig({
  plugins: [
    vue(),
    viteCompression({
      ext: '.gz', // gz br
      algorithm: 'gzip', // brotliCompress gzip
      deleteOriginFile: false, // 打包完成后删除源文件
    }),
    styleImport({}),
    autoImport({
      imports: ['vue', 'vue-router'],
      dts: './src/auto-import.d.ts',
    })
  ],
  resolve: {
    alias: {
      '@': resolve(__dirname, 'src'),
    },
  },
  base: './', // 打包基础路径 不配置打包后可能会找不到资源
  server: {
    host: '0.0.0.0',
    open: true,
    proxy: {
      '/qy-api': {
        target: 'http://117.122.212.102:8092/qy-api', // 测试服务
        changeOrigin: true,
        rewrite: (path) => path.replace(/^\/qy-api/, ''),
      },
      '/wx': {
        target: 'https://open.weixin.qq.com', // 测试服务
        changeOrigin: true,
        rewrite: (path) => path.replace(/^\/wx/, ''),
      },
    },
    port: 8888, // 启动时的默认占用端口
  },
  build: {
    outDir: 'dist',
    rollupOptions: {
      output: {
        entryFileNames: `assets/[name].${buildTimeStep}.js`,
        chunkFileNames: `assets/[name].${buildTimeStep}.js`,
        assetFileNames: `assets/[name].${buildTimeStep}.[ext]`
      }
    }
  }
});
